==> mobile_pos-0.8.16.tar.gz: example/lib/app.dart <==
import 'package:flutter/material.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';

class RavenPayExampleApp extends StatefulWidget {
  const RavenPayExampleApp({super.key});

  @override
  State<RavenPayExampleApp> createState() => _RavenPayExampleAppState();
}

class _RavenPayExampleAppState extends State<RavenPayExampleApp> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        body: Center(
            child: ElevatedButton(
                onPressed: () async {
                  await RavenBankBoxPlugin.launch(context,
                      config: BankBoxConfig(
                          logo: Container(
                            height: 32,
                            width: 32,
                            decoration: const BoxDecoration(
                                shape: BoxShape.circle,
                                color: Color(0xffEA872D)),
                            child: Padding(
                              padding: const EdgeInsets.all(12),
                              child: Image.asset('assets/logo.png'),
                            ),
                          ),
                          onClose: () {
                            //user taps close button
                            Navigator.pop(context);
                          },
                          showTerminals: true,
                          enableBalanceCheck: true,
                          showLabel: true,
                          theme: const MobilePOSTheme(
                              headerTextColor: Color(0xFF755AE2),
                              primaryColor: Color(0xFF755AE2),
                              onPrimary: Colors.white,
                              secondaryColor: Color(0xFFEA872D)),
                          enviroment: BankBoxEnviroment.staging,
                          appInfo: AppInfo(
                              appName: 'CIPHER',
                              appId: '89dca95cee33f4d965172740a323243e',
                              appEmail: 'syleyeghele@gmail.com'),
                          customerInfo: CustomerInfo(
                            lastName: 'Nnodim',
                            firstName: 'Prisca',
                            bvn: '6386487383',
                            email: 'syleyeghele+1@gmail.com',
                            phone: '08166106863',
                          ),
                          onSuccess: (data) {
                            print(data);
                          },
                          onError: (error) {
                            print(error.message);
                          }));
                },
                child: const Text("Start Payment"))));
  }
}

==> mobile_pos-0.8.18.tar.gz: example/lib/app.dart <==
import 'package:flutter/material.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';

class RavenPayExampleApp extends StatefulWidget {
  const RavenPayExampleApp({super.key});

  @override
  State<RavenPayExampleApp> createState() => _RavenPayExampleAppState();
}

class _RavenPayExampleAppState extends State<RavenPayExampleApp> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        body: Center(
            child: ElevatedButton(
                onPressed: () async {
                  await RavenBankBoxPlugin.launch(context,
                      config: BankBoxConfig(
                          logo: Container(
                            height: 32,
                            width: 32,
                            decoration: const BoxDecoration(
                                shape: BoxShape.circle,
                                color: Color(0xffEA872D)),
                            child: Padding(
                              padding: const EdgeInsets.all(12),
                              child: Image.asset('assets/logo.png'),
                            ),
                          ),
                          onClose: () {
                            //user taps close button
                            Navigator.pop(context);
                          },
                          showTerminals: true,
                          enableBalanceCheck: true,
                          showLabel: true,
                          theme: const MobilePOSTheme(
                              headerTextColor: Color(0xFF755AE2),
                              primaryColor: Color(0xFF755AE2),
                              onPrimary: Colors.white,
                              secondaryColor: Color(0xFFEA872D)),
                          enviroment: BankBoxEnviroment.staging,
                          appInfo: AppInfo(
                              appName: 'CIPHER',
                              appId: '89dca95cee33f4d965172740a323243e',
                              appEmail: 'syleyeghele+1@gmail.com'),
                          customerInfo: CustomerInfo(
                            lastName: 'Nnodim',
                            firstName: 'Prisca',
                            bvn: '6386487383',
                            email: 'syleyeghele+1@gmail.com',
                            phone: '08166106863',
                          ),
                          onSuccess: (data) {
                            print(data);
                          },
                          onError: (error) {
                            print(error.message);
                          }));
                },
                child: const Text("Start Payment"))));
  }
}
